@@ -172,15 +172,9 @@ update_scan_label (void)
 	gchar *available;
 	GtkWidget *label;
 
-	#if GLIB_CHECK_VERSION (2, 30, 0)
 		total = g_format_size (baobab.fs.total);
 		used = g_format_size (baobab.fs.used);
 		available = g_format_size (baobab.fs.avail);
-	#else
-		total = g_format_size_for_display (baobab.fs.total);
-		used = g_format_size_for_display (baobab.fs.used);
-		available = g_format_size_for_display (baobab.fs.avail);
-	#endif
 	
 	/* Translators: these are labels for disk space */
 	markup = g_markup_printf_escaped  ("<small>%s <b>%s</b> (%s %s %s %s )</small>",
@@ -195,6 +189,7 @@ update_scan_label (void)
 	label = GTK_WIDGET (gtk_builder_get_object (baobab.main_ui, "label1"));
 
 	gtk_label_set_markup (GTK_LABEL (label), markup);
+	g_free (markup);
 }
 
 void
@@ -389,11 +384,7 @@ first_row (void)
 
 	gtk_tree_store_append (baobab.model, &root_iter, NULL);
 	
-	#if GLIB_CHECK_VERSION (2, 30, 0)
 		capacity_size = g_format_size (baobab.fs.total);
-	#else
-		capacity_size = g_format_size_for_display (baobab.fs.total);
-	#endif
 	
 	capacity_label = g_strdup (_("Total filesystem capacity"));
 	gtk_tree_store_set (baobab.model, &root_iter,
@@ -410,11 +401,7 @@ first_row (void)
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (baobab.tree_view), FALSE);
 	gtk_tree_store_append (baobab.model, &firstiter, &root_iter);
 	
-	#if GLIB_CHECK_VERSION (2, 30, 0)
 		size = g_format_size (baobab.fs.used);
-	#else
-		size = g_format_size_for_display (baobab.fs.used);
-	#endif
 		
 	if (baobab.fs.total == 0 && baobab.fs.used == 0) {
 		perc = 100.0;
@@ -462,11 +449,7 @@ baobab_fill_model (struct chan_data *data)
 
 	hardlinks = g_string_new ("");
 	if (data->tempHLsize > 0) {
-		#if GLIB_CHECK_VERSION (2, 30, 0)
 			size = g_format_size (data->tempHLsize);
-		#else
-			size = g_format_size_for_display (data->tempHLsize);
-		#endif
 			
 		g_string_assign (hardlinks, "<i>(");
 		g_string_append (hardlinks, _("contains hardlinks for:"));
@@ -481,13 +464,8 @@ baobab_fill_model (struct chan_data *data)
 			 ngettext ("%5d item", "%5d items",
 				   data->elements), data->elements);
 
-	#if GLIB_CHECK_VERSION (2, 30, 0)
 		size = g_format_size (data->size);
 		alloc_size = g_format_size (data->alloc_size);
-	#else
-		size = g_format_size_for_display (data->size);
-		alloc_size = g_format_size_for_display (data->alloc_size);
-	#endif
 	
 	gtk_tree_store_set (baobab.model, &iter,
 			    COL_DIR_NAME, name,
@@ -716,6 +694,10 @@ baobab_create_statusbar (void)
 		return;
 	}
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
+	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (baobab.statusbar), TRUE);
+#endif
+
 	g_settings_bind (baobab.ui_settings,
 			 BAOBAB_SETTINGS_STATUSBAR_VISIBLE,
 			 baobab.statusbar, "visible",
@@ -893,7 +875,6 @@ baobab_init (void)
 
 	baobab_create_toolbar ();
 	baobab_create_statusbar ();
-
 	baobab_setup_monitors ();
 
 	g_signal_connect (baobab.ui_settings, "changed::" BAOBAB_SETTINGS_SUBFLSTIPS_VISIBLE,
@@ -1261,7 +1242,7 @@ main (int argc, char *argv[])
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	g_set_application_name ("Baobab");
+	g_set_application_name (_("Disk Usage Analyzer"));
 
 	context = g_option_context_new (NULL);
 	g_option_context_set_ignore_unknown_options (context, FALSE);
