@@ -27,9 +27,9 @@
 
 #include <glib/gi18n.h>
 #include <gio/gio.h>
+#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gtk/gtk.h>
 
 #include "gdict-applet.h"
 #include "gdict-about.h"
@@ -278,14 +278,14 @@ window_key_press_event_cb (GtkWidget   *widget,
 {
   GdictApplet *applet = GDICT_APPLET (user_data);
   
-  if (event->keyval == GDK_Escape)
+  if (event->keyval == GDK_KEY_Escape)
     {
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (applet->priv->toggle), FALSE);
       gtk_toggle_button_toggled (GTK_TOGGLE_BUTTON (applet->priv->toggle));
 
       return TRUE;
     }
-  else if ((event->keyval == GDK_l) &&
+  else if ((event->keyval == GDK_KEY_l) &&
 	   (event->state & GDK_CONTROL_MASK))
     {
       gtk_widget_grab_focus (applet->priv->entry);
@@ -449,7 +449,7 @@ gdict_applet_entry_key_press_cb (GtkWidget   *widget,
 {
   GdictAppletPrivate *priv = GDICT_APPLET (user_data)->priv;
   
-  if (event->keyval == GDK_Escape)
+  if (event->keyval == GDK_KEY_Escape)
     {
       if (priv->is_window_showing)
 	{
@@ -459,7 +459,7 @@ gdict_applet_entry_key_press_cb (GtkWidget   *widget,
 	  return TRUE;
 	}
     }
-  else if (event->keyval == GDK_Tab)
+  else if (event->keyval == GDK_KEY_Tab)
     {
       if (priv->is_window_showing)
 	gtk_widget_grab_focus (priv->defbox);
@@ -742,6 +742,7 @@ gdict_applet_cmd_help (GtkAction *action,
     }
 }
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
 static void
 gdict_applet_change_background (MatePanelApplet               *applet,
 				MatePanelAppletBackgroundType  type,
@@ -754,6 +755,7 @@ gdict_applet_change_background (MatePanelApplet               *applet,
     								       color,
     								       pixmap);
 }
+#endif
 
 static void
 gdict_applet_change_orient (MatePanelApplet       *applet,
@@ -1111,7 +1113,9 @@ gdict_applet_class_init (GdictAppletClass *klass)
   widget_class->size_allocate = gdict_applet_size_allocate;
   widget_class->style_set = gdict_applet_style_set;
   
+#if !GTK_CHECK_VERSION (3, 0, 0)
   applet_class->change_background = gdict_applet_change_background;
+#endif
   applet_class->change_orient = gdict_applet_change_orient;
   
   g_type_class_add_private (gobject_class, sizeof (GdictAppletPrivate));
