@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -187,15 +187,3 @@ gdict_show_gerror_dialog (GtkWindow   *parent,
   g_error_free (error);
   error = NULL;
 }
-
-gchar *
-gdict_mateconf_get_string_with_default (MateConfClient *client,
-				     const gchar *key,
-				     const gchar *def)
-{
-  gchar *val;
-
-  val = mateconf_client_get_string (client, key, NULL);
-  return val ? val : g_strdup (def);
-}
-
