@@ -470,14 +470,13 @@ gdict_source_dialog_response_cb (GtkDialog *dialog,
       break;
     case GTK_RESPONSE_HELP:
       gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (dialog)),
-                    "ghelp:mate-dictionary#mate-dictionary-add-source",
+                    "help:mate-dictionary/mate-dictionary-add-source",
                     gtk_get_current_event_time (), &err);
       if (err)
         {
           gdict_show_gerror_dialog (GTK_WINDOW (dialog),
           			    _("There was an error while displaying help"),
           		 	    err);
-          g_error_free (err);
         }
 
       /* we don't want the dialog to close itself */
